MethodChannelFlutterSystemRingtones class
Android implementation of FlutterSystemRingtonesPlatform via method channel.
- Inheritance
-
- Object
- PlatformInterface
- FlutterSystemRingtonesPlatform
- MethodChannelFlutterSystemRingtones
Constructors
- MethodChannelFlutterSystemRingtones()
- Creates the default method-channel implementation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
Channel used to communicate with
FlutterSystemRingtonesPluginon Android.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAlarms(
) → Future< List< Ringtone> ?> -
Loads alarm-type system sounds, or
nullif the platform returns nothing.override -
getNotifications(
) → Future< List< Ringtone> ?> -
Loads notification-type system sounds, or
nullif the platform returns nothing.override -
getRingtones(
) → Future< List< Ringtone> ?> -
Loads ringtone-type system sounds, or
nullif the platform returns nothing.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseRingtoneList(
dynamic raw, [String method = 'unknown']) → List< Ringtone> ? - Parses a native method-channel payload into Ringtone instances.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited